@@ -3,8 +3,8 @@
  *
  * Multiple file upload component with progress-bar, drag-and-drop, support for all modern browsers.
  *
- * Original version: 1.0 © 2010 Andrew Valums ( andrew(at)valums.com )
- * Current Maintainer (2.0+): © 2012, Ray Nicholus ( fineuploader(at)garstasio.com )
+ * Original version: 1.0  2010 Andrew Valums ( andrew(at)valums.com )
+ * Current Maintainer (2.0+):  2012, Ray Nicholus ( fineuploader(at)garstasio.com )
  *
  * Licensed under MIT license, GNU GPL 2 or later, GNU LGPL 2 or later, see license.txt.
  */
@@ -72,7 +72,7 @@ var qq = function(element) {
          */
         css: function(styles) {
             if (styles.opacity !== null){
-                if (typeof element.style.opacity !== 'string' && typeof(element.filters) !== 'undefined'){
+                if (typeof element.style.opacity !== 'string' && typeof(element.filters) !== 'indefinido'){
                     styles.filter = 'alpha(opacity=' + Math.round(100 * styles.opacity) + ')';
                 }
             }
@@ -614,12 +614,12 @@ qq.FineUploaderBasic = function(o){
             onValidate: function(fileData) {} // return false to prevent upload
         },
         messages: {
-            typeError: "{file} has an invalid extension. Valid extension(s): {extensions}.",
-            sizeError: "{file} is too large, maximum file size is {sizeLimit}.",
-            minSizeError: "{file} is too small, minimum file size is {minSizeLimit}.",
-            emptyError: "{file} is empty, please select files again without it.",
-            noFilesError: "No files to upload.",
-            onLeave: "The files are being uploaded, if you leave now the upload will be cancelled."
+            typeError: "{file} Tiene una extensin invlida. Extensiones vlidas: {extensions}.",
+            sizeError: "{file} es muy grande, el tamao mximo es {sizeLimit}.",
+            minSizeError: "{file} es muy pequeo, el tamao minimo es {minSizeLimit}.",
+            emptyError: "{file} esta vaco, favor de volver a seleccionar los archivos.",
+            noFilesError: "No hay archivos.",
+            onLeave: "Los archivos se estn cargando, si abandonas la pgina la carga se cancelar."
         },
         retry: {
             enableAuto: false,
@@ -1511,11 +1511,11 @@ qq.FineUploader = function(o){
         },
         text: {
             uploadButton: 'Upload a file',
-            cancelButton: 'Cancel',
+            cancelButton: 'Cancel
             retryButton: 'Retry',
             failUpload: 'Upload failed',
-            dragZone: 'Drop files here to upload',
-            dropProcessing: 'Processing dropped files...',
+            dragZone: 'Drag and drop files here to upload',
+            dropProcessing: 'Processing...',
             formatProgress: "{percent}% of {total_size}",
             waitingForResponse: "Processing..."
         },
@@ -1554,8 +1554,8 @@ qq.FineUploader = function(o){
             retry: 'qq-upload-retry',
             statusText: 'qq-upload-status-text',
 
-            success: 'qq-upload-success',
-            fail: 'qq-upload-fail',
+            success: 'alert alert-success',
+            fail: 'alert alert-error',
 
             successIcon: null,
             failIcon: null,
@@ -1570,11 +1570,11 @@ qq.FineUploader = function(o){
             enableTooltip: true
         },
         messages: {
-            tooManyFilesError: "You may only drop one file"
+            tooManyFilesError: "Slo se puede arrastrar un archivo"
         },
         retry: {
             showAutoRetryNote: true,
-            autoRetryNote: "Retrying {retryNum}/{maxAuto}...",
+            autoRetryNote: "Volviendo a intentar {retryNum}/{maxAuto}...",
             showButton: false
         },
         showMessage: function(message){
@@ -1911,7 +1911,7 @@ qq.extend(qq.FineUploader.prototype, {
                 this.log("'" + responseProperty + "' is not a valid property on the server response.", 'warn');
             }
 
-            qq(this._find(item, 'statusText')).setText(shortFailureReason || failureReason);
+            qq(this._find(item, 'statusText')).setText(failureReason);
 
             if (this._options.failedUploadTextDisplay.enableTooltip) {
                 this._showTooltip(item, failureReason);
